To do list
==========

- `Alternative syntax for blocks with decorator and context manager
  <https://foss.heptapod.net/fluiddyn/transonic/issues/6>`_

- Type hints: `Shape <https://foss.heptapod.net/fluiddyn/transonic/issues/9>`_

Inline to do items
------------------

.. todolist::
